@@ -56,15 +56,6 @@ sub get_backup_path
   return (&get_base_path () . "/backup");
 }
 
-
-sub get_data_path
-{
-  my $path = &get_base_path (). "/data";
-  chmod (0755, $path);
-  return $path;
-}
-
-
 # Give a command, and it will put in C locale, some sane PATH values and find
 # the program to run in the path. Redirects stderr to null.
 sub do_get_cmd_path
@@ -89,6 +80,8 @@ sub get_cmd_path
    my ($cmd) = @_;
 
    my $command = &do_get_cmd_path ($cmd);
+
+   return -1 if ($command == -1);
    return ("LC_ALL=C PATH=\$PATH:/sbin:/usr/sbin $command 2> /dev/null");
 }
 
@@ -456,7 +449,7 @@ sub run_pipe
   {
     $command = &get_cmd_path ($cmd);
   }
-  
+
   if ($command == -1)
   {
     &Utils::Report::do_report ("file_run_pipe_failed", $command);
@@ -464,7 +457,7 @@ sub run_pipe
     return undef;
   }
 
-  $command .= " |"        if $mode_mask & $FILE_READ;
+  $command .= " |" if $mode_mask & $FILE_READ;
   $command = "| $command > /dev/null" if $mode_mask & $FILE_WRITE;
 
   open PIPE, $command;
